#
# spec file for package python-devpi-common
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-devpi-common
Version:        4.0.3
Release:        1.4
Summary:        Utilities jointly used by devpi-server and devpi-client
License:        MIT
URL:            https://github.com/devpi/devpi
Source:         https://files.pythonhosted.org/packages/source/d/devpi-common/devpi-common-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lazy
Requires:       python-packaging
Requires:       python-requests >= 2.3.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module py >= 1.4.20}
BuildRequires:  %{python_module lazy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.3.0}
# /SECTION
%python_subpackages

%description
Utilities jointly used by devpi-server and devpi-client.

%prep
%autosetup -p1 -n devpi-common-%{version}
rm tox.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG README.rst
%license LICENSE
%{python_sitelib}/devpi_common
%{python_sitelib}/devpi_common-%{version}.dist-info

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.3:
  * Add ``is_prerelease`` and other methods to ``LegacyVersion``
    to fix ``get_sorted_versions`` with ``stable=True`` and some
    other cases.
* Wed Oct 18 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.2:
  * Bug Fixes
    + Do not mark commands with returncode ``None`` from tox 4.x as failed.
    + Restore flushing after each written line in new TerminalWriter.
    + Fix #939: custom legacy version parsing (non PEP 440) after
    packaging >= 22.0 removed support.
  * Deprecations and Removals
    + Removed ``HTMLPage`` class originally vendored from pip.
    + Dropped support for Python <= 3.6.
  * Features
    + Add ``chdir`` context handler in devpi_common.contextlib.
    + Hide username from URL representation.
    + Added stripped down TerminalWriter from ``py`` library which only
    supports coloring.
- Switch to pyproject macros.
- Drop patch unpin-versions.patch, no longer required.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Mar 22 2023 Dirk Müller <dmueller@suse.com>
- add unpin-versions.patch to reduce the packaging version conflict
* Mon Mar  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken tests with new packaging module because invalid
  version
- Update to version 3.7.2
  * Fix #928: correct default for pre-release matching after switching
    from ``pkg_resources`` to ``packaging``.
  * Fix #949: correct parsing of wheel tags for Python 3.10 and above.
- 3.7.1 (2022-12-16)
  * Fix #939: pin packaging to <22 as it removed the deprecated
    LegacyVersion.
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.7.0
  Features
  Add hash_type and fragment attributes to URL class.
  Replace pkg_resources usage with packaging.
  Bug Fixes
  Fix #895: return content of data-yanked.
  Fixed some cases where name and version weren’t split off correctly from filename.
* Mon Aug  2 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.6.0
  * support data-yanked attribute in HTMLPage parser.
  * Replace “cached_property” with “lazy” package, which uses __dict__
    directly for much faster reads.
  * Hide password from URL representation.
  * Allow replacement of individual netloc parts with URL.replace method.
* Tue Sep 10 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v3.4.0
* Thu Mar 21 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v3.3.1
* Fri Dec 12 2014 tbechtold@suse.com
- Initial version v2.0.4
